@@ -1,4 +1,4 @@
-package Config::Structured;
+package Config::Structured 2.006;
 use v5.22;
 use warnings;
 
